@@ -97,3 +97,49 @@ def get_str_md5sum(content):
 def append_text_file(file_name, file_content):
     with open(file_name,"a") as file:
         file.write(file_content)
+
+def replace_line_in_file(file_path, old_line_number, new_line_content):
+    import fileinput
+    line_number = 0
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            line_number = line_number + 1;
+            if line_number == old_line_number:
+                print(new_line_content, end='')
+            else:
+                print(line, end='')
+
+def insert_line_at_top_of_file(file_path, new_line_content, new_line_content_end='\n'):
+    import fileinput
+    flag_inserted = False
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            if flag_inserted == False:
+                print(new_line_content, end=new_line_content_end)
+                flag_inserted = True
+            print(line, end='')
+
+def add_line_in_file(file_path, old_line_number, new_line_content, new_line_content_end='\n'):
+    import fileinput
+    line_number = 0
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            line_number = line_number + 1;
+            if line_number == old_line_number:
+                print(new_line_content, end=new_line_content_end)
+            print(line, end='')
+
+def del_line_in_file(file_path, old_line_number):
+    import fileinput
+    line_number = 0
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            line_number = line_number + 1;
+            if line_number == old_line_number:
+                pass
+            else:
+                print(line, end='')
+
+def read_text_file(file_path):
+    from pathlib import Path
+    return Path(file_path).read_text()
